#! /bin/bash

#export DYLD_LIBRARY_PATH=$HOME/ffmpeg-0.8_0.9/lib:$DYLD_LIBRARY_PATH
export DYLD_LIBRARY_PATH=$HOME/ffmpeg-2.2.3/lib:$DYLD_LIBRARY_PATH

#JAVA_HOME=`/usr/libexec/java_home -version 1.8`
JAVA_HOME=`/usr/libexec/java_home -version 11`
PATH=$JAVA_HOME/bin:$PATH
export JAVA_HOME PATH

spath=`dirname $0`

. $spath/tests.sh  $JAVA_HOME/bin/java -DummyArg ../build-macosx-java6 $*


